@@ -3,7 +3,7 @@
 ;; Copyright (C) 2020 GDQuest
 
 ;; Author: Nathan Lovato <nathan@gdquest.com>, Fabián E. Gallina <fgallina@gnu.org>
-;; URL: https://github.com/GDQuest/emacs-gdscript-mode/
+;; URL: https://github.com/godotengine/emacs-gdscript-mode/
 ;; Package-Requires: ((emacs "26.3"))
 ;; Maintainer: nathan@gdquest.com
 ;; Created: Feb 2020
@@ -272,17 +272,19 @@ possibilities can be narrowed to specific indentation points."
          (current-column)))
       (`(,(or :after-block-start
               :after-backslash-first-line
-              :after-backslash-assignment-continuation
               :inside-paren-newline-start) . ,start)
        ;; Add one indentation level.
        (goto-char start)
        (+ (current-indentation) gdscript-indent-offset))
       (`(,(or :inside-paren
               :after-backslash-block-continuation
-              :after-backslash-dotted-continuation) . ,start)
-       ;; Use the column given by the context.
+              :after-backslash-dotted-continuation
+	      :after-backslash-assignment-continuation) . ,start)
+       ;; Use (possibly extra) indentation given by the configuration
        (goto-char start)
-       (current-column))
+       (+ (current-indentation)
+	  (* gdscript-indent-offset
+	     gdscript-indent-line-continuation-scale)))
       (`(:after-block-end . ,start)
        ;; Subtract one indentation level.
        (goto-char start)
@@ -344,11 +346,7 @@ to the maximum available level.  When indentation is the minimum
 possible and PREVIOUS is non-nil, cycle back to the maximum
 level."
   (let ((follow-indentation-p
-         ;; Check if point is within indentation.
-         (and (<= (line-beginning-position) (point))
-              (>= (+ (line-beginning-position)
-                     (current-indentation))
-                  (point)))))
+         (<= (current-column) (current-indentation))))
     (save-excursion
       (indent-line-to
        (gdscript-indent-calculate-indentation previous))
