@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "gdscript-mode" "1.4.0"
+(define-package "gdscript-mode" "20251104.1437"
   "Major mode for Godot's GDScript language."
   '((emacs "26.3"))
-  :url "https://github.com/GDQuest/emacs-gdscript-mode/"
-  :commit "ef7a7f2789d0708a624a93b0f7037dd057cd8532"
-  :revdesc "ef7a7f2789d0"
+  :url "https://github.com/godotengine/emacs-gdscript-mode/"
+  :commit "e94dfd9dc7a50261b2c41ae3daa05043331a54a8"
+  :revdesc "e94dfd9dc7a5"
   :keywords '("languages")
   :authors '(("Nathan Lovato" . "nathan@gdquest.com")
              ("Fabián E. Gallina" . "fgallina@gnu.org"))
